# KsponSpeech

## About the corpus

KsponSpeech is a large-scale spontaneous speech corpus of Korean. This corpus contains 965.2 hours of general
open-domain dialog utterances with transcriptions.

More information can be found
at https://www.mdpi.com/2076-3417/10/19/6936

Training and evaluation transcripts were generated the same way as in the above paper.

## Prepare data

You can download KsponSpeech at https://aihub.or.kr/aidata/105/download

Run following script to unzip the downloaded file

```bash
./unzip_ksponspeech.sh "PATH_TO_DOWNLOADED/한국어 음성" PATH_TO_UNZIPPED
```

pcm files need to be converted to wav for training. Run following script for the conversion.

```bash
python conert_to_wav.py --dirpath PATH_TO_UNZIPPED --nj num_processes
```

## How to run an ASR experiment with KsponSpeech

To train a full speech recognition system the pipeline is the following:

1. **Train a tokenizer.** The tokenizer takes in input the training transcripts and determines the subword units that
   will be used for both acoustic and language model training. **Training a tokenizer before the language and acoustic
   model is necessary**. Indeed, both of them will reuse this tokenizer to map the output tokens.
2. **Train a Language Model (LM).** The language model takes in input long texts from available books. We have recipes
   with RNN and transformer-based LMs. In both cases, the LM is used during beam search to assign different weights to
   different hypotheses generated by the acoustic model.
3. **Train an acoustic model (AM).** The acoustic model maps the input speech into a set of sub-words units. The current
   repository contains recipes for transformer-based systems.

**The results obtained with the different models can be found in the corresponding sub-directories!**

## How to simply use pretrained models to transcribe my audio file?

SpeechBrain provides a simple interface to transcribe audio files with pretrained models. All the necessary information
can be found on the HuggingFace repositories corresponding to our models for KsponSpeech:

- [Conformer + ctc + TransformerLM](https://huggingface.co/speechbrain/asr-conformer-transformerlm-ksponspeech)
- [Colab example](https://colab.research.google.com/drive/10N98aGoeLGfh6Hu6xOCH5BbjVTVYgCyB?usp=sharing)

# Citing SpeechBrain
Please, cite SpeechBrain if you use it for your research or business.

```bibtex
@misc{speechbrain,
  title={{SpeechBrain}: A General-Purpose Speech Toolkit},
  author={Mirco Ravanelli and Titouan Parcollet and Peter Plantinga and Aku Rouhe and Samuele Cornell and Loren Lugosch and Cem Subakan and Nauman Dawalatabad and Abdelwahab Heba and Jianyuan Zhong and Ju-Chieh Chou and Sung-Lin Yeh and Szu-Wei Fu and Chien-Feng Liao and Elena Rastorgueva and François Grondin and William Aris and Hwidong Na and Yan Gao and Renato De Mori and Yoshua Bengio},
  year={2021},
  eprint={2106.04624},
  archivePrefix={arXiv},
  primaryClass={eess.AS},
  note={arXiv:2106.04624}
}
```

# Citing this recipe
```bibtex
@misc{returnzero,
  title = {ReturnZero Conformer Korean ASR model},
  author = {Dongwon Kim and Dongwoo Kim and Roh Jeongkyu},
  year = {2021},
  howpublished = {\url{https://huggingface.co/ddwkim/asr-conformer-transformerlm-ksponspeech}},
}
```

# Citing KsponSpeech dataset
```bibtex
@Article{app10196936,
AUTHOR = {Bang, Jeong-Uk and Yun, Seung and Kim, Seung-Hi and Choi, Mu-Yeol and Lee, Min-Kyu and Kim, Yeo-Jeong and Kim, Dong-Hyun and Park, Jun and Lee, Young-Jik and Kim, Sang-Hun},
TITLE = {KsponSpeech: Korean Spontaneous Speech Corpus for Automatic Speech Recognition},
JOURNAL = {Applied Sciences},
VOLUME = {10},
YEAR = {2020},
NUMBER = {19},
ARTICLE-NUMBER = {6936},
URL = {https://www.mdpi.com/2076-3417/10/19/6936},
ISSN = {2076-3417},
DOI = {10.3390/app10196936}
}
```
